<a href="https://pypi.org/project/clawpack/"><img alt="PyPI" src="https://img.shields.io/pypi/v/clawpack"></a>
<a href="https://pepy.tech/project/clawpack"><img alt="Downloads" src="https://pepy.tech/badge/clawpack"></a>
<a href="https://anaconda.org/conda-forge/clawpack/"><img alt="conda-forge" src="https://img.shields.io/conda/dn/conda-forge/clawpack.svg?label=conda-forge"></a>

Please see the documentation for Clawpack at http://www.clawpack.org.

If you are cloning this repository, the following pages may be of particular interest:

- <a href="http://www.clawpack.org/developers.html#installation-instructions-for-developers">Installation instructions for Developers'</a> (or more generally from this repository),
- <a href="http://www.clawpack.org/installing.html">Other installation options,</a>
- <a href="http://www.clawpack.org/packages.html">Which Clawpack solver should I use?</a>
- <a href="http://www.clawpack.org/developers.html">Developers' Guide</a>, including guidelines for contributing to the project,
- <a href="http://www.clawpack.org/regression.html">Regression testing,</a>
- <a href="http://www.clawpack.org/git_versions.html">Keeping track of repository versions with git,</a>
- <a href="http://www.clawpack.org/community.html">Clawpack Community,</a> with links to Google groups, issue trackers, Developers' workshops, etc.


